@@ -7,19 +7,19 @@
 #include "modelverificationpoint.h"
 #include "testhelper.h"
 
-#include <applicationcontroller.h>
-#include <favoritelocationmodel.h>
-#include <livedatamanager.h>
-#include <locationinformation.h>
-#include <pkpassmanager.h>
-#include <reservationmanager.h>
-#include <timelinemodel.h>
-#include <tripgroupmanager.h>
-#include <transfermanager.h>
-#include <weatherinformation.h>
+#include "applicationcontroller.h"
+#include "favoritelocationmodel.h"
+#include "livedatamanager.h"
+#include "locationinformation.h"
+#include "pkpassmanager.h"
+#include "reservationmanager.h"
+#include "timelinemodel.h"
+#include "tripgroupmanager.h"
+#include "transfermanager.h"
+#include "weatherinformation.h"
 
-#include <weatherforecast.h>
-#include <weatherforecastmanager.h>
+#include "weatherforecast.h"
+#include "weatherforecastmanager.h"
 
 #include <KItinerary/Flight>
 #include <KItinerary/Place>
@@ -97,6 +97,7 @@ private Q_SLOTS:
         ctrl->setReservationManager(&resMgr);
 
         TimelineModel model;
+        model.setCurrentDateTime({{2024, 3, 31}, {17, 18}});
         QAbstractItemModelTester tester(&model);
         model.setReservationManager(&resMgr);
 
@@ -109,24 +110,32 @@ private Q_SLOTS:
 
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
-        QCOMPARE(insertSpy.size(), 1);
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
+        QCOMPARE(insertSpy.size(), 2);
         QCOMPARE(insertSpy.at(0).at(1).toInt(), 0);
         QCOMPARE(insertSpy.at(0).at(2).toInt(), 0);
-        QVERIFY(updateSpy.isEmpty());
-        QCOMPARE(model.rowCount(), 2);
+        QCOMPARE(updateSpy.size(), 1);
+        QCOMPARE(model.rowCount(), 3);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
+        QCOMPARE(model.index(1, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo); // DST change
+        QCOMPARE(model.index(2, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
 
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v2.pkpass")));
+        insertSpy.clear();
+        updateSpy.clear();
+        rmSpy.clear();
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/boardingpass-v2.pkpass")));
         QCOMPARE(insertSpy.size(), 1);
         QCOMPARE(updateSpy.size(), 1);
         QCOMPARE(updateSpy.at(0).at(0).toModelIndex().row(), 0);
-        QCOMPARE(model.rowCount(), 2);
+        QCOMPARE(model.rowCount(), 3);
 
+        insertSpy.clear();
+        updateSpy.clear();
+        rmSpy.clear();
         Test::clearAll(&resMgr);
-        QCOMPARE(insertSpy.size(), 1);
-        QCOMPARE(updateSpy.size(), 1);
-        QCOMPARE(rmSpy.size(), 1);
+        QCOMPARE(insertSpy.size(), 0);
+        QCOMPARE(updateSpy.size(), 0);
+        QCOMPARE(rmSpy.size(), 2);
         QCOMPARE(model.rowCount(), 1);
     }
 
@@ -138,6 +147,7 @@ private Q_SLOTS:
         ctrl->setReservationManager(&resMgr);
 
         TimelineModel model;
+        model.setCurrentDateTime({{2024, 3, 29}, {11, 38}});
         QAbstractItemModelTester tester(&model);
         model.setHomeCountryIsoCode(QStringLiteral("DE"));
         model.setReservationManager(&resMgr);
@@ -151,14 +161,14 @@ private Q_SLOTS:
 
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v1.json")));
-        QCOMPARE(insertSpy.size(), 3);
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/haus-randa-v1.json")));
+        QCOMPARE(insertSpy.size(), 4);
         QCOMPARE(insertSpy.at(0).at(1).toInt(), 0);
         QCOMPARE(insertSpy.at(0).at(2).toInt(), 0);
         QCOMPARE(insertSpy.at(1).at(1).toInt(), 1);
         QCOMPARE(insertSpy.at(1).at(2).toInt(), 1);
         QVERIFY(updateSpy.isEmpty());
-        QCOMPARE(model.rowCount(), 4);
+        QCOMPARE(model.rowCount(), 5);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
         QCOMPARE(model.index(1, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Hotel);
         QCOMPARE(model.index(1, 0).data(TimelineModel::ElementRangeRole), TimelineElement::RangeBegin);
@@ -166,21 +176,27 @@ private Q_SLOTS:
         QCOMPARE(model.index(2, 0).data(TimelineModel::ElementRangeRole), TimelineElement::RangeEnd);
 
         // move end date of a hotel booking: dataChanged on RangeBegin, move (or del/ins) on RangeEnd
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/haus-randa-v2.json")));
-        QCOMPARE(insertSpy.size(), 5);
+        insertSpy.clear();
+        updateSpy.clear();
+        rmSpy.clear();
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/haus-randa-v2.json")));
+        QCOMPARE(insertSpy.size(), 3);
         QCOMPARE(updateSpy.size(), 1);
-        QCOMPARE(rmSpy.size(), 2);
+        QCOMPARE(rmSpy.size(), 3);
         QCOMPARE(updateSpy.at(0).at(0).toModelIndex().row(), 1);
-        QCOMPARE(insertSpy.at(2).at(1).toInt(), 0);
-        QCOMPARE(insertSpy.at(2).at(2).toInt(), 0);
+        QCOMPARE(insertSpy.at(1).at(1).toInt(), 0);
+        QCOMPARE(insertSpy.at(1).at(2).toInt(), 0);
         QCOMPARE(rmSpy.at(0).at(1), 2);
-        QCOMPARE(model.rowCount(), 4);
+        QCOMPARE(model.rowCount(), 5);
 
         // delete a split element
+        insertSpy.clear();
+        updateSpy.clear();
+        rmSpy.clear();
         const auto resId = model.data(model.index(1, 0), TimelineModel::BatchIdRole).toString();
         QVERIFY(!resId.isEmpty());
         resMgr.removeReservation(resId);
-        QCOMPARE(rmSpy.size(), 5);
+        QCOMPARE(rmSpy.size(), 4);
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
     }
@@ -193,6 +209,7 @@ private Q_SLOTS:
         ctrl->setReservationManager(&resMgr);
 
         TimelineModel model;
+        model.setCurrentDateTime({{2024, 3, 29}, {10, 21}}); // after the DST transition in the US!
         QAbstractItemModelTester tester(&model);
         model.setHomeCountryIsoCode(QStringLiteral("DE"));
         model.setReservationManager(&resMgr);
@@ -200,8 +217,8 @@ private Q_SLOTS:
         QCOMPARE(model.rowCount(), 1);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
 
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
-        QCOMPARE(model.rowCount(), 5); //  2x country info, 2x flights, today marker
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        QCOMPARE(model.rowCount(), 6); //  2x country info, 2x flights, today marker, 1x DST info
 
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
         QCOMPARE(model.index(1, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
@@ -216,15 +233,19 @@ private Q_SLOTS:
         QCOMPARE(countryInfo.drivingSide(), KItinerary::KnowledgeDb::DrivingSide::Right);
         QCOMPARE(countryInfo.drivingSideDiffers(), false);
         QCOMPARE(countryInfo.powerPlugCompatibility(), LocationInformation::Incompatible);
-        QCOMPARE(model.index(4, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
+        countryInfo = model.index(4, 0).data(TimelineModel::LocationInformationRole).value<LocationInformation>();
+        QCOMPARE(countryInfo.isDst(), true);
+        QCOMPARE(countryInfo.dstDiffers(), true);
+        QCOMPARE(model.index(5, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
 
         // remove the GB flight should also remove the GB country info
         auto resId = model.index(0, 0).data(TimelineModel::BatchIdRole).toString();
         resMgr.removeReservation(resId);
-        QCOMPARE(model.rowCount(), 3);
+        QCOMPARE(model.rowCount(), 4);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
         QCOMPARE(model.index(1, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
-        QCOMPARE(model.index(2, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
+        QCOMPARE(model.index(2, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
+        QCOMPARE(model.index(3, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
 
         // remove the US flight should also remove the US country info
         resId = model.index(0, 0).data(TimelineModel::BatchIdRole).toString();
@@ -403,8 +424,8 @@ private Q_SLOTS:
         model.setReservationManager(&resMgr);
         model.setWeatherForecastManager(&weatherMgr);
 
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/weather-no-location-change.json")));
-        ModelVerificationPoint vp0(QLatin1String(SOURCE_DIR "/data/weather-no-location-change.model"));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/weather-no-location-change.json")));
+        ModelVerificationPoint vp0(QLatin1StringView(SOURCE_DIR "/data/weather-no-location-change.model"));
         vp0.setRoleFilter({TimelineModel::BatchIdRole});
         QVERIFY(vp0.verify(&model));
     }
@@ -418,6 +439,7 @@ private Q_SLOTS:
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&resMgr);
         TimelineModel model;
+        model.setCurrentDateTime({{2024, 3, 29}, {10, 21}}); // after the DST transition in the US!
         QAbstractItemModelTester tester(&model);
         model.setReservationManager(&resMgr);
         QCOMPARE(model.rowCount(), 1); // 1x TodayMarker
@@ -430,29 +452,33 @@ private Q_SLOTS:
         QVERIFY(rmSpy.isValid());
 
         // full import at runtime
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
-        QCOMPARE(model.rowCount(), 3); // 2x Flight, 1x TodayMarger
-        QCOMPARE(insertSpy.count(), 2);
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
+        QCOMPARE(model.rowCount(), 4); // 2x Flight, 1x DST info, 1x TodayMarker
         QCOMPARE(updateSpy.count(), 2);
+        QCOMPARE(updateSpy.count(), 2);
+        QCOMPARE(rmSpy.count(), 3);
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
         QCOMPARE(model.index(1, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
-        QCOMPARE(model.index(2, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
+        QCOMPARE(model.index(2, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
+        QCOMPARE(model.index(3, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
         QCOMPARE(resMgr.reservationsForBatch(model.index(0, 0).data(TimelineModel::BatchIdRole).toString()).size(), 2);
         QCOMPARE(resMgr.reservationsForBatch(model.index(1, 0).data(TimelineModel::BatchIdRole).toString()).size(), 2);
 
         // already existing data
         model.setReservationManager(nullptr);
         model.setReservationManager(&resMgr);
-        QCOMPARE(model.rowCount(), 3); // 2x Flight, 1x TodayMarger
+        QCOMPARE(model.rowCount(), 4); // 2x Flight, 1x DST info, 1x TodayMarger
         QCOMPARE(model.index(0, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
         QCOMPARE(model.index(1, 0).data(TimelineModel::ElementTypeRole), TimelineElement::Flight);
-        QCOMPARE(model.index(2, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
+        QCOMPARE(model.index(2, 0).data(TimelineModel::ElementTypeRole), TimelineElement::LocationInfo);
+        QCOMPARE(model.index(3, 0).data(TimelineModel::ElementTypeRole), TimelineElement::TodayMarker);
         QCOMPARE(resMgr.reservationsForBatch(model.index(0, 0).data(TimelineModel::BatchIdRole).toString()).size(), 2);
         QCOMPARE(resMgr.reservationsForBatch(model.index(1, 0).data(TimelineModel::BatchIdRole).toString()).size(), 2);
 
         // update splits element
         updateSpy.clear();
         insertSpy.clear();
+        rmSpy.clear();
         auto resId = model.index(1, 0).data(TimelineModel::BatchIdRole).toString();
         QVERIFY(!resId.isEmpty());
         auto res = resMgr.reservation(resId).value<FlightReservation>();
@@ -460,10 +486,10 @@ private Q_SLOTS:
         flight.setDepartureTime(flight.departureTime().addDays(1));
         res.setReservationFor(flight);
         resMgr.updateReservation(resId, res);
-        QCOMPARE(model.rowCount(), 4);
+        QCOMPARE(model.rowCount(), 5);
         QCOMPARE(updateSpy.count(), 1);
-        QCOMPARE(insertSpy.count(), 1);
-        QCOMPARE(rmSpy.count(), 0);
+        QCOMPARE(insertSpy.count(), 2);
+        QCOMPARE(rmSpy.count(), 1);
 
         // update merges two elements
         updateSpy.clear();
@@ -472,17 +498,17 @@ private Q_SLOTS:
         flight.setDepartureTime(flight.departureTime().addDays(-1));
         res.setReservationFor(flight);
         resMgr.updateReservation(resId, res);
-        QCOMPARE(model.rowCount(), 3);
+        QCOMPARE(model.rowCount(), 4);
         QCOMPARE(updateSpy.count(), 1);
-        QCOMPARE(rmSpy.count(), 1);
-        QCOMPARE(insertSpy.count(), 0);
+        QCOMPARE(rmSpy.count(), 3);
+        QCOMPARE(insertSpy.count(), 2);
 
         // removal of merged items
         updateSpy.clear();
         rmSpy.clear();
         Test::clearAll(&resMgr);
         QCOMPARE(model.rowCount(), 1);
-        QCOMPARE(rmSpy.count(), 2);
+        QCOMPARE(rmSpy.count(), 6);
         QCOMPARE(updateSpy.count(), 2);
     }
 
@@ -502,25 +528,25 @@ private Q_SLOTS:
         model.setReservationManager(&resMgr);
         model.setWeatherForecastManager(&weatherMgr);
 
-        ModelVerificationPoint vp0(QLatin1String(SOURCE_DIR "/data/timeline/daychange-r0.model"));
+        ModelVerificationPoint vp0(QLatin1StringView(SOURCE_DIR "/data/timeline/daychange-r0.model"));
         vp0.setRoleFilter({TimelineModel::BatchIdRole});
         QVERIFY(vp0.verify(&model));
 
         // changing the day should move the today marker
         model.setCurrentDateTime(QDateTime({2196, 10, 15}, {0, 15}));
-        ModelVerificationPoint vp1(QLatin1String(SOURCE_DIR "/data/timeline/daychange-r1.model"));
+        ModelVerificationPoint vp1(QLatin1StringView(SOURCE_DIR "/data/timeline/daychange-r1.model"));
         vp1.setRoleFilter({TimelineModel::BatchIdRole});
         QVERIFY(vp1.verify(&model));
 
         // load something to define the current location, so we get weather
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
-        ModelVerificationPoint vp2(QLatin1String(SOURCE_DIR "/data/timeline/daychange-r2.model"));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/flight-txl-lhr-sfo.json")));
+        ModelVerificationPoint vp2(QLatin1StringView(SOURCE_DIR "/data/timeline/daychange-r2.model"));
         vp2.setRoleFilter({TimelineModel::BatchIdRole});
         QVERIFY(vp2.verify(&model));
 
         // changing the day should move the today marker and weather one day forward
         model.setCurrentDateTime(QDateTime({2196, 10, 16}, {19, 30}));
-        ModelVerificationPoint vp3(QLatin1String(SOURCE_DIR "/data/timeline/daychange-r3.model"));
+        ModelVerificationPoint vp3(QLatin1StringView(SOURCE_DIR "/data/timeline/daychange-r3.model"));
         vp3.setRoleFilter({TimelineModel::BatchIdRole});
         QVERIFY(vp3.verify(&model));
     }
@@ -529,7 +555,7 @@ private Q_SLOTS:
     {
         QTest::addColumn<QString>("baseName");
 
-        QDirIterator it(QLatin1String(SOURCE_DIR "/data/timeline/"), {QLatin1String("*.json")});
+        QDirIterator it(QLatin1StringView(SOURCE_DIR "/data/timeline/"), {QLatin1StringView("*.json")});
         while (it.hasNext()) {
             it.next();
             const auto baseName = it.fileInfo().baseName();
@@ -544,7 +570,7 @@ private Q_SLOTS:
         Test::clearAll(&resMgr);
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&resMgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/") + baseName + QLatin1StringView(".json")));
         TripGroupManager groupMgr;
         groupMgr.setReservationManager(&resMgr);
         WeatherForecastManager weatherMgr;
@@ -581,14 +607,14 @@ private Q_SLOTS:
         model.setTransferManager(&transferMgr);
 
         // check state is correct for data imported at the start
-        ModelVerificationPoint vp(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".model"));
+        ModelVerificationPoint vp(QLatin1StringView(SOURCE_DIR "/data/timeline/") + baseName + QLatin1StringView(".model"));
         vp.setRoleFilter({TimelineModel::BatchIdRole, TimelineModel::TripGroupIdRole});
         vp.setJsonPropertyFilter({QStringLiteral("reservationId")});
         QVERIFY(vp.verify(&model));
 
         // retry with loading during runtime
         Test::clearAll(&resMgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/timeline/") + baseName + QLatin1String(".json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/") + baseName + QLatin1StringView(".json")));
         QVERIFY(vp.verify(&model));
     }
 
@@ -606,8 +632,8 @@ private Q_SLOTS:
 
         QSignalSpy currentResChangedSpy(&model, &TimelineModel::currentBatchChanged);
 
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/../tests/randa2017.json")));
-        QCOMPARE(model.rowCount(), 13);
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
+        QCOMPARE(model.rowCount(), 14);
         QVERIFY(!currentResChangedSpy.empty());
 
         model.setCurrentDateTime(QDateTime({2017, 8, 1}, {23, 0}, QTimeZone("Europe/Zurich")));
