@@ -7,11 +7,11 @@
 #include "modelverificationpoint.h"
 #include "testhelper.h"
 
-#include <applicationcontroller.h>
-#include <reservationmanager.h>
-#include <timelinemodel.h>
-#include <tripgroupmanager.h>
-#include <tripgroupproxymodel.h>
+#include "applicationcontroller.h"
+#include "reservationmanager.h"
+#include "timelinemodel.h"
+#include "tripgroupmanager.h"
+#include "tripgroupproxymodel.h"
 
 #include <QAbstractItemModelTester>
 #include <QtTest/qtest.h>
@@ -47,9 +47,9 @@ private Q_SLOTS:
         Test::clearAll(&resMgr);
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&resMgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/timeline/multi-traveler-merge-with-countryinfo.json")));
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/../tests/randa2017.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/multi-traveler-merge-with-countryinfo.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
 
         TripGroupManager groupMgr;
         QSignalSpy addSpy(&groupMgr, &TripGroupManager::tripGroupAdded);
@@ -70,22 +70,22 @@ private Q_SLOTS:
         proxy.expand(addSpy.at(1).at(0).toString());
         proxy.expand(addSpy.at(2).at(0).toString());
 
-        ModelVerificationPoint vp0(QLatin1String(SOURCE_DIR "/data/tripgroupproxy/expand-collapse-r0.model"));
+        ModelVerificationPoint vp0(QLatin1StringView(SOURCE_DIR "/data/tripgroupproxy/expand-collapse-r0.model"));
         vp0.setRoleFilter({TimelineModel::BatchIdRole, TimelineModel::TripGroupIdRole});
         QVERIFY(vp0.verify(&proxy));
 
         proxy.collapse(addSpy.at(0).at(0).toString());
-        ModelVerificationPoint vp1(QLatin1String(SOURCE_DIR "/data/tripgroupproxy/expand-collapse-r1.model"));
+        ModelVerificationPoint vp1(QLatin1StringView(SOURCE_DIR "/data/tripgroupproxy/expand-collapse-r1.model"));
         vp1.setRoleFilter({TimelineModel::BatchIdRole, TimelineModel::TripGroupIdRole});
         QVERIFY(vp1.verify(&proxy));
 
         proxy.collapse(addSpy.at(1).at(0).toString());
-        ModelVerificationPoint vp2(QLatin1String(SOURCE_DIR "/data/tripgroupproxy/expand-collapse-r2.model"));
+        ModelVerificationPoint vp2(QLatin1StringView(SOURCE_DIR "/data/tripgroupproxy/expand-collapse-r2.model"));
         vp2.setRoleFilter({TimelineModel::BatchIdRole, TimelineModel::TripGroupIdRole});
         QVERIFY(vp2.verify(&proxy));
 
         proxy.collapse(addSpy.at(2).at(0).toString());
-        ModelVerificationPoint vp3(QLatin1String(SOURCE_DIR "/data/tripgroupproxy/expand-collapse-r3.model"));
+        ModelVerificationPoint vp3(QLatin1StringView(SOURCE_DIR "/data/tripgroupproxy/expand-collapse-r3.model"));
         vp3.setRoleFilter({TimelineModel::BatchIdRole, TimelineModel::TripGroupIdRole});
         QVERIFY(vp3.verify(&proxy));
 
@@ -103,7 +103,7 @@ private Q_SLOTS:
         Test::clearAll(&resMgr);
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&resMgr);
-        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/../tests/randa2017.json")));
+        ctrl->importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/randa2017.json")));
 
         TripGroupManager groupMgr;
         QSignalSpy addSpy(&groupMgr, &TripGroupManager::tripGroupAdded);
@@ -122,13 +122,13 @@ private Q_SLOTS:
         proxy.setSourceModel(&model);
 
         // future event, should be expanded
-        ModelVerificationPoint vp0(QLatin1String(SOURCE_DIR "/data/tripgroupproxy/current-r0.model"));
+        ModelVerificationPoint vp0(QLatin1StringView(SOURCE_DIR "/data/tripgroupproxy/current-r0.model"));
         vp0.setRoleFilter({TimelineModel::BatchIdRole, TimelineModel::TripGroupIdRole});
         QVERIFY(vp0.verify(&proxy));
 
         // current event, must be expanded and not collapsible
         model.setCurrentDateTime(QDateTime({2017, 9, 14}, {12, 34}));
-        ModelVerificationPoint vp1(QLatin1String(SOURCE_DIR "/data/tripgroupproxy/current-r1.model"));
+        ModelVerificationPoint vp1(QLatin1StringView(SOURCE_DIR "/data/tripgroupproxy/current-r1.model"));
         vp1.setRoleFilter({TimelineModel::BatchIdRole, TimelineModel::TripGroupIdRole});
         QVERIFY(vp1.verify(&proxy));
         proxy.collapse(addSpy.at(0).at(0).toString());
@@ -136,9 +136,9 @@ private Q_SLOTS:
 
         // past event, should be collapsed
         model.setCurrentDateTime(QDateTime({2018, 9, 9}, {12, 34}));
-        ModelVerificationPoint vp2(QLatin1String(SOURCE_DIR "/data/tripgroupproxy/current-r2.model"));
+        ModelVerificationPoint vp2(QLatin1StringView(SOURCE_DIR "/data/tripgroupproxy/current-r2.model"));
         vp2.setRoleFilter({TimelineModel::BatchIdRole, TimelineModel::TripGroupIdRole});
-        QCOMPARE(proxy.rowCount(), 2);
+        QCOMPARE(proxy.rowCount(), 3);
         QVERIFY(vp2.verify(&proxy));
     }
 
