@@ -10,13 +10,14 @@
 #include "locationinformation.h"
 #include "pkpassmanager.h"
 #include "reservationmanager.h"
+#include "timelineelement.h"
 #include "tripgroup.h"
 #include "tripgroupmanager.h"
 #include "transfermanager.h"
 #include "weatherinformation.h"
 
-#include <weatherforecast.h>
-#include <weatherforecastmanager.h>
+#include "weatherforecast.h"
+#include "weatherforecastmanager.h"
 
 #include <KItinerary/BusTrip>
 #include <KItinerary/CountryDb>
@@ -231,7 +232,7 @@ QVariant TimelineModel::data(const QModelIndex& index, int role) const
                 return {};
             }
             const auto resIds = m_resMgr->reservationsForBatch(elem.batchId());
-            QVector<QVariant> v;
+            QList<QVariant> v;
             v.reserve(resIds.size());
             for (const auto &resId : resIds) {
                 v.push_back(m_resMgr->reservation(resId));
@@ -515,6 +516,44 @@ void TimelineModel::updateInformationElements()
         previousCountry = newCountry;
     }
 
+    // add DST transition information in a -1/+3 months window, if there are any
+    if (!m_elements.empty()) {
+        qDebug() << "looking for DST transitions";
+        constexpr const auto DST_DAYS_BEFORE = 30;
+        constexpr const auto DST_DAYS_AFTER = 90;
+        for (auto it = m_elements.begin(); it != m_elements.end(); ++it) {
+            if ((*it).isInformational() || (*it).isCanceled()) {
+                continue;
+            }
+            const auto tz = timeZone((*it).endDateTime());
+            auto startDt = std::max((*it).dt, now().addDays(-DST_DAYS_BEFORE));
+            auto endDt = now().addDays(DST_DAYS_AFTER);
+            for (auto nextIt = it; std::next(nextIt) != m_elements.end();) {
+                ++nextIt;
+                if ((*nextIt).isInformational() || (*nextIt).isCanceled()) {
+                    continue;
+                }
+                endDt = std::min(endDt, (*nextIt).dt);
+                break;
+            }
+            if (startDt > now().addDays(DST_DAYS_AFTER) || endDt < now().addDays(-DST_DAYS_BEFORE) || !tz.isValid() || !tz.hasTransitions() || !tz.hasDaylightTime()) {
+                continue;
+            }
+            while (startDt < endDt) {
+                const auto nextTransition = tz.nextTransition(startDt);
+                if (!nextTransition.atUtc.isValid() || nextTransition.atUtc >= endDt) {
+                    break;
+                }
+                startDt = nextTransition.atUtc;
+                LocationInformation locInfo;
+                locInfo.setTimeZone(tz, startDt);
+                it = insertOrUpdate(it, TimelineElement(this, TimelineElement::LocationInfo, startDt, QVariant::fromValue(locInfo)));
+            }
+        }
+
+        qDebug() << "  done";
+    }
+
     updateWeatherElements();
 }
 
@@ -781,11 +820,31 @@ void TimelineModel::transferRemoved(const QString &resId, Transfer::Alignment al
     Q_EMIT todayRowChanged();
 }
 
-static bool isSelectableElement(const TimelineElement &elem)
+[[nodiscard]] static bool isSelectableElement(const TimelineElement &elem)
 {
     return elem.isReservation() && elem.rangeType == TimelineElement::SelfContained;
 }
 
+// same as SortUtil::endDateTime but with a lower bound estimate
+// when the end time isn't available
+[[nodiscard]] static QDateTime estimatedEndTime(const QVariant &res)
+{
+    if (SortUtil::hasEndTime(res)) {
+        return SortUtil::endDateTime(res);
+    }
+    if (JsonLd::isA<FlightReservation>(res)) {
+        const auto flight = res.value<FlightReservation>().reservationFor().value<Flight>();
+        const auto dist = LocationUtil::distance(flight.departureAirport().geo(), flight.arrivalAirport().geo());
+        if (std::isnan(dist) || !flight.departureTime().isValid()) {
+            return {};
+        }
+        auto dt = flight.departureTime();
+        return dt.addSecs((qint64)(dist * 250.0 / 3.6)); // see flightutil.cpp in kitinerary
+    }
+
+    return {};
+}
+
 QString TimelineModel::currentBatchId() const
 {
     if (m_elements.empty()) {
@@ -809,9 +868,9 @@ QString TimelineModel::currentBatchId() const
         for (; it != m_elements.begin() && (it == m_elements.end() || !isSelectableElement(*it)); --it) {}
     }
 
-    const auto resId = (*it).batchId();
+    auto resId = (*it).batchId();
     const auto res = m_resMgr->reservation(resId);
-    auto endTime = SortUtil::endDateTime(res);
+    auto endTime = estimatedEndTime(res);
     if (endTime.secsTo(now()) > Constants::CurrentBatchTrailingMargin.count()) {
         endTime = {};
     }
